@@ -54,7 +54,7 @@ else:
 import threading
 
 from mercurial import demandimport
-demandimport.ignore.extend([
+demandimport.IGNORES.update([
     'win32com.shell',
     'numpy',  # comtypes.npsupport does try-import
     'tortoisehg.util.config',
