@@ -116,7 +116,7 @@ class AboutDialog(QDialog):
         self._readsettings()
 
         # Spawn it later, so that the dialog gets visible quickly.
-        QTimer.singleShot(0, self.getUpdateInfo)
+        QTimer.singleShot(1000, self.getUpdateInfo)
         self._newverreply = None
 
     def getVersionInfo(self):
@@ -169,9 +169,7 @@ class AboutDialog(QDialog):
         except (IndexError, ImportError, ValueError):
             pass
         try:
-            thgv = version.version()
-            if '+' in thgv:
-                thgv = thgv[:thgv.index('+')]
+            thgv = version.package_version()
             curver = tuple([int(p) for p in thgv.split('.')])
         except ValueError:
             curver = (0,0,0)
