@@ -26,7 +26,7 @@ from .qtgui import (
 
 from mercurial import (
     error,
-    util,
+    scmutil,
 )
 
 from ..util import hglib
@@ -158,11 +158,11 @@ class BisectDialog(QDialog):
 
     def _lookupRevision(self, changeid):
         try:
-            ctx = self.repo[hglib.fromunicode(changeid)]
+            ctx = scmutil.revsymbol(self.repo, hglib.fromunicode(changeid))
             return ctx.rev()
         except (error.LookupError, error.RepoLookupError), e:
             self._stbar.showMessage(hglib.tounicode(str(e)))
-        except util.Abort, e:
+        except error.Abort, e:
             if e.hint:
                 err = _('%s (hint: %s)') % (hglib.tounicode(str(e)),
                                             hglib.tounicode(e.hint))
