@@ -43,6 +43,9 @@ from .qtgui import (
 )
 
 from mercurial import util
+from mercurial.utils import (
+    dateutil,
+)
 
 from ..util import (
     colormap,
@@ -1043,7 +1046,7 @@ class _AnnotateViewControl(_AbstractViewControl):
         def getauthor(fctx):
             return hglib.tounicode(hglib.username(fctx.user()))
         def getdate(fctx):
-            return util.shortdate(fctx.date())
+            return dateutil.shortdate(fctx.date())
         if self._fd.rev() is None:
             p1rev = self._fd.parentRevs()[0]
             revfmt = '%%%dd%%c' % len(str(p1rev))
@@ -1115,12 +1118,16 @@ class _AnnotateViewControl(_AbstractViewControl):
         links = []
         fctxcache = {}  # (path, rev): fctx
         for l in data[0]['lines']:
-            path, rev = l['file'], l['rev']
+            try:
+                path, rev, lineno = l['path'], l['rev'], l['lineno']
+            except KeyError:
+                # hg<4.8 (34ba47117164, 47cb6750dea3)
+                path, rev, lineno = l['file'], l['rev'], l['line_number']
             try:
                 fctx = fctxcache[path, rev]
             except KeyError:
                 fctx = fctxcache[path, rev] = repo[rev][path]
-            links.append((fctx, l['line_number']))
+            links.append((fctx, lineno))
         self._links = links
         self._updateView()
 
