@@ -5,18 +5,50 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2, incorporated herein by reference.
 
+from __future__ import absolute_import
+
 import os
 import re
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from .qtcore import (
+    QEvent,
+    QSettings,
+    QTimer,
+    Qt,
+    pyqtSignal,
+)
+from .qtgui import (
+    QAbstractItemView,
+    QComboBox,
+    QDialog,
+    QDialogButtonBox,
+    QGroupBox,
+    QHBoxLayout,
+    QLabel,
+    QLineEdit,
+    QListWidget,
+    QMenu,
+    QPushButton,
+    QSplitter,
+    QVBoxLayout,
+)
 
-from mercurial import commands, match, ui, util, error
+from mercurial import (
+    commands,
+    error,
+    match,
+    util,
+)
 
-from tortoisehg.hgqt.i18n import _
-from tortoisehg.util import shlib, hglib
-
-from tortoisehg.hgqt import qtlib, qscilib
+from ..util import (
+    hglib,
+    shlib,
+)
+from ..util.i18n import _
+from . import (
+    qscilib,
+    qtlib,
+)
 
 class HgignoreDialog(QDialog):
     'Edit a repository .hgignore file'
@@ -35,7 +67,7 @@ class HgignoreDialog(QDialog):
         self._repoagent = repoagent
         self.pats = pats
         self.setWindowTitle(_('Ignore filter - %s') % repoagent.displayName())
-        self.setWindowIcon(qtlib.geticon('ignore'))
+        self.setWindowIcon(qtlib.geticon('thg-ignore'))
 
         vbox = QVBoxLayout()
         self.setLayout(vbox)
@@ -125,7 +157,7 @@ class HgignoreDialog(QDialog):
         QTimer.singleShot(0, self.refresh)
 
         s = QSettings()
-        self.restoreGeometry(s.value('hgignore/geom').toByteArray())
+        self.restoreGeometry(qtlib.readByteArray(s, 'hgignore/geom'))
 
     @property
     def repo(self):
@@ -225,7 +257,7 @@ class HgignoreDialog(QDialog):
             try:
                 match.match(self.repo.root, '', [], [test])
                 self.insertFilters([newfilter], False)
-            except util.Abort, inst:
+            except error.Abort, inst:
                 qtlib.WarningMsgBox(_('Invalid glob expression'), str(inst),
                                     parent=self)
                 return
@@ -235,7 +267,7 @@ class HgignoreDialog(QDialog):
                 match.match(self.repo.root, '', [], [test])
                 re.compile(test)
                 self.insertFilters([newfilter], True)
-            except (util.Abort, re.error), inst:
+            except (error.Abort, re.error), inst:
                 qtlib.WarningMsgBox(_('Invalid regexp expression'), str(inst),
                                     parent=self)
                 return
@@ -262,7 +294,7 @@ class HgignoreDialog(QDialog):
         except (EnvironmentError, error.RepoError), e:
             qtlib.WarningMsgBox(_('Unable to read repository status'),
                                 uni(str(e)), parent=self)
-        except util.Abort, e:
+        except error.Abort, e:
             if e.hint:
                 err = _('%s (hint: %s)') % (uni(str(e)), uni(e.hint))
             else:
@@ -283,15 +315,15 @@ class HgignoreDialog(QDialog):
         for i, u in enumerate(self.lclunknowns):
             if u in self.pats:
                 item = self.unknownlist.item(i)
-                self.unknownlist.setItemSelected(item, True)
+                item.setSelected(True)
                 self.unknownlist.setCurrentItem(item)
-                self.le.setText(QString(u))
+                self.le.setText(u)
         self.pats = []
 
     def writeIgnoreFile(self):
         eol = self.doseoln and '\r\n' or '\n'
         out = eol.join(self.ignorelines) + eol
-        hasignore = os.path.exists(self.repo.join(self.ignorefile))
+        hasignore = os.path.exists(self.repo.vfs.join(self.ignorefile))
 
         try:
             f = util.atomictempfile(self.ignorefile, 'wb', createmode=None)
@@ -304,7 +336,7 @@ class HgignoreDialog(QDialog):
                                              'add this file to the source code '
                                              'control repository?'), parent=self)
                 if ret:
-                    commands.add(ui.ui(), self.repo, self.ignorefile)
+                    commands.add(hglib.loadui(), self.repo, self.ignorefile)
             shlib.shell_notify([self.ignorefile])
             self.ignoreFilterUpdated.emit()
         except EnvironmentError, e:
