@@ -5,21 +5,64 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-import os
+from __future__ import absolute_import
+
 import errno
+import os
 
-from mercurial import extensions, error, util
+from .qtcore import (
+    QAbstractTableModel,
+    QPointF,
+    QRectF,
+    Qt,
+    pyqtSlot,
+)
+from .qtgui import (
+    QAbstractItemView,
+    QCheckBox,
+    QColor,
+    QDialog,
+    QDialogButtonBox,
+    QHBoxLayout,
+    QLabel,
+    QLineEdit,
+    QMenu,
+    QPainter,
+    QPainterPath,
+    QPen,
+    QPixmap,
+    QPolygonF,
+    QSizePolicy,
+    QSplitter,
+    QStackedWidget,
+    QTableView,
+    QToolBar,
+    QVBoxLayout,
+    QWidget,
+    QWidgetAction,
+)
 
-from tortoisehg.hgqt import qtlib, cmdcore, cmdui, update, revdetails
-from tortoisehg.hgqt.qtlib import geticon
-from tortoisehg.util import hglib
-from tortoisehg.util.i18n import _
+from mercurial import (
+    error,
+    extensions,
+)
+from mercurial.utils import (
+    dateutil,
+)
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from ..util import hglib
+from ..util.i18n import _
+from . import (
+    cmdcore,
+    cmdui,
+    qtlib,
+    revdetails,
+    update,
+)
+from .qtlib import geticon
 
 PATCHCACHEPATH = 'thgpbcache'
-nullvariant = QVariant()
+nullvariant = None
 
 class PatchBranchWidget(QWidget, qtlib.TaskWidget):
     '''
@@ -96,7 +139,7 @@ class PatchBranchWidget(QWidget, qtlib.TaskWidget):
 
         def PatchList():
             self.patchlistmodel = PatchBranchModel(self.compute_model(),
-                                                   self.repo.changectx('.').branch(),
+                                                   self.repo['.'].branch(),
                                                    self)
             self.patchlist = QTableView(self)
             self.patchlist.setModel(self.patchlistmodel)
@@ -157,7 +200,7 @@ class PatchBranchWidget(QWidget, qtlib.TaskWidget):
         # compute model data
         self.patchlistmodel.setModel(
             self.compute_model(),
-            self.repo.changectx('.').branch() )
+            self.repo['.'].branch())
 
         # restore patch selection
         if selname:
@@ -400,13 +443,13 @@ class PatchBranchWidget(QWidget, qtlib.TaskWidget):
         model = self.patchlistmodel
         col = model._columns.index('Name')
         patchIndex = model.createIndex(index.row(), col)
-        return str(model.data(patchIndex).toString())
+        return str(model.data(patchIndex))
 
     def updatePatchCache(self, patchname):
         # TODO: Parameters should include rev, as one patch may have several heads
         # rev should be appended to filename and used by pdiff
         assert(len(patchname)>0)
-        cachepath = self.repo.join(PATCHCACHEPATH)
+        cachepath = self.repo.vfs.join(PATCHCACHEPATH)
         # TODO: Fix this - it looks ugly
         try:
             os.mkdir(cachepath)
@@ -415,7 +458,7 @@ class PatchBranchWidget(QWidget, qtlib.TaskWidget):
                 raise
         # TODO: Convert filename if any funny characters are present
         patchfile = os.path.join(cachepath, patchname)
-        dirstate = self.repo.join('dirstate')
+        dirstate = self.repo.vfs.join('dirstate')
         try:
             patch_age = os.path.getmtime(patchfile) - os.path.getmtime(dirstate)
         except:
@@ -425,7 +468,7 @@ class PatchBranchWidget(QWidget, qtlib.TaskWidget):
             pf = open(patchfile, 'wb')
             try:
                 pf.writelines(self.pdiff(patchname))
-            #  except (util.Abort, error.RepoError), e:
+            #  except (error.Abort, error.RepoError), e:
             #      # Do something with str(e)
             finally:
                 pf.close()
@@ -449,7 +492,7 @@ class PatchBranchWidget(QWidget, qtlib.TaskWidget):
         if len(indexes) == 0:
             return None
         index = indexes[0]
-        return str(index.sibling(index.row(), C_NAME).data().toString())
+        return str(index.sibling(index.row(), C_NAME).data())
 
     def show_patch_cmenu(self, pos):
         """Context menu for selected patch"""
@@ -667,13 +710,13 @@ class PatchBranchModel(QAbstractTableModel):
         column = self._columns[index.column()]
         gnode = self.model[row]
         ctx = None
-        #ctx = self.repo.changectx(gnode.rev)
+        #ctx = self.repo[gnode.rev]
 
         if role == Qt.DisplayRole:
             text = self._columnmap[column](ctx, gnode)
-            if not isinstance(text, (QString, unicode)):
+            if not isinstance(text, unicode):
                 text = hglib.tounicode(text)
-            return QVariant(text)
+            return text
         elif role == Qt.ForegroundRole:
             return gnode.node.color
         elif role == Qt.DecorationRole:
@@ -684,9 +727,9 @@ class PatchBranchModel(QAbstractTableModel):
     def headerData(self, section, orientation, role):
         if orientation == Qt.Horizontal:
             if role == Qt.DisplayRole:
-                return QVariant(self._headers[section])
+                return self._headers[section]
             if role == Qt.TextAlignmentRole:
-                return QVariant(Qt.AlignLeft)
+                return Qt.AlignLeft
         return nullvariant
 
     # end of functions required to subclass QAbstractTableModel
@@ -813,7 +856,7 @@ class PatchBranchModel(QAbstractTableModel):
             circle(0.5 * radius)
 
         painter.end()
-        return QVariant(pix)
+        return pix
 
 class PNewDialog(QDialog):
     def __init__(self, parent=None):
@@ -861,7 +904,7 @@ class PNewDialog(QDialog):
         layout.addWidget(DialogButtons())
 
         self.patchdatele.setText(
-                hglib.tounicode(hglib.displaytime(util.makedate())))
+                hglib.tounicode(hglib.displaytime(dateutil.makedate())))
 
     def patchname(self):
         return self.patchnamele.text()
