@@ -6,11 +6,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2, incorporated herein by reference.
 
-shortlicense = '''
-Copyright (C) 2008-2018 Steve Borho <steve@borho.org> and others.
-This is free software; see the source for copying conditions.  There is NO
-warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-'''
+from __future__ import absolute_import
 
 import getopt
 import os
@@ -18,20 +14,46 @@ import pdb
 import sys
 import subprocess
 
-from mercurial import util, fancyopts, cmdutil, extensions, error, scmutil
-from mercurial import pathutil, registrar
+from mercurial import (
+    cmdutil,
+    error,
+    extensions,
+    fancyopts,
+    pathutil,
+    registrar,
+    scmutil,
+    util,
+)
+from mercurial.utils import (
+    stringutil,
+)
 
-from tortoisehg.util.i18n import agettext as _
-from tortoisehg.util import hglib, paths, i18n
-from tortoisehg.util import version as thgversion
-from tortoisehg.hgqt import qtapp, qtlib, thgrepo
-from tortoisehg.hgqt import cmdui, quickop
+from ..util import (
+    hglib,
+    i18n,
+    paths,
+    version as thgversion,
+)
+from ..util.i18n import agettext as _
+from . import (
+    cmdui,
+    qtapp,
+    qtlib,
+    quickop,
+    thgrepo,
+)
 
 try:
     from tortoisehg.util.config import nofork as config_nofork
 except ImportError:
     config_nofork = None
 
+shortlicense = '''
+Copyright (C) 2008-2018 Steve Borho <steve@borho.org> and others.
+This is free software; see the source for copying conditions.  There is NO
+warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+'''
+
 console_commands = 'help thgstatus version'
 nonrepo_commands = '''userconfig shellconfig clone init debugblockmatcher
 debugbugreport about help version thgstatus serve rejects log'''
@@ -205,7 +227,9 @@ def _parse(ui, args):
         sys.exit()
     else:
         alias, args = 'workbench', []
-    aliases, i = cmdutil.findcmd(alias, table, ui.config("ui", "strict"))
+    # copies hg<4.8 (fa88170c10bb) behavior
+    stable = {k.lstrip('^'): e for k, e in table.items()}
+    aliases, i = cmdutil.findcmd(alias, stable, ui.config("ui", "strict"))
     for a in aliases:
         if a.startswith(alias):
             alias = a
@@ -710,8 +734,10 @@ def help_(ui, name=None, with_version=False, **opts):
             version(ui)
             ui.write('\n')
 
+        # copies hg<4.8 (fa88170c10bb) behavior
+        stable = {k.lstrip('^'): e for k, e in table.items()}
         try:
-            aliases, i = cmdutil.findcmd(name, table, False)
+            aliases, i = cmdutil.findcmd(name, stable, False)
         except error.AmbiguousCommand, inst:
             select = lambda c: c.lstrip('^').startswith(inst.args[0])
             helplist(_('list of commands:\n\n'), select)
@@ -749,6 +775,7 @@ def help_(ui, name=None, with_version=False, **opts):
             if (not select and name != 'shortlist' and
                 e[0].__module__ != __name__):
                 continue
+            # TODO: switch to hg>=4.8 (fa88170c10bb) syntax
             if name == "shortlist" and not f.startswith("^"):
                 continue
             f = f.lstrip("^")
@@ -775,9 +802,10 @@ def help_(ui, name=None, with_version=False, **opts):
                 commands = cmds[f].replace("|",", ")
                 ui.write(" %s:\n      %s\n"%(commands, h[f]))
             else:
-                ui.write('%s\n' % (util.wrap(h[f], textwidth,
-                                             initindent=' %-*s   ' % (m, f),
-                                             hangindent=' ' * (m + 4))))
+                ui.write('%s\n'
+                         % (stringutil.wrap(h[f], textwidth,
+                                            initindent=' %-*s   ' % (m, f),
+                                            hangindent=' ' * (m + 4))))
 
         if not ui.quiet:
             addglobalopts(True)
@@ -846,9 +874,9 @@ def help_(ui, name=None, with_version=False, **opts):
             if second:
                 initindent = ' %-*s  ' % (opts_len, first)
                 hangindent = ' ' * (opts_len + 3)
-                ui.write('%s\n' % (util.wrap(second, textwidth,
-                                             initindent=initindent,
-                                             hangindent=hangindent)))
+                ui.write('%s\n' % (stringutil.wrap(second, textwidth,
+                                                   initindent=initindent,
+                                                   hangindent=hangindent)))
             else:
                 ui.write("%s\n" % first)
 
